#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hgmp
version:              0.1.2.1
visibility:           public
id:                   hgmp-0.1.2.1-37KhDUJWIyoBudy9ZaZT2Q
key:                  hgmp-0.1.2.1-37KhDUJWIyoBudy9ZaZT2Q
license:              BSD-3-Clause
copyright:            2016,2017 Claude Heiland-Allen
maintainer:           claude@mathr.co.uk
author:               Claude Heiland-Allen
homepage:             https://code.mathr.co.uk/hgmp
synopsis:             Haskell interface to GMP
description:
    Types and instances, and marshalling between Integer and
    Rational and the corresponding GMP types, along with raw
    foreign imports of GMP functions.  Allows FFI to GMP code
    (whether in GMP itself or in third-party code that uses
    GMP).

    Supports only GHC with integer-gmp or ghc-bignum, this
    might change if there'\''s any demand.

category:             Numeric
abi:                  9b7b4c2a733fb9a72c7849a26a2b53f8
exposed:              True
exposed-modules:
    Numeric.GMP.Raw.Safe Numeric.GMP.Raw.Unsafe Numeric.GMP.Types
    Numeric.GMP.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hgmp-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hgmp-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hgmp-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hgmp
hs-libraries:         HShgmp-0.1.2.1-37KhDUJWIyoBudy9ZaZT2Q
depends:              base-4.18.2.1 ghc-bignum-1.3 ghc-prim-0.10.0
haddock-interfaces:   /usr/share/doc/haskell-hgmp/html/hgmp.haddock
haddock-html:         /usr/share/doc/haskell-hgmp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

